[Schmitzm-commits] r2333 - in trunk: schmitzm-core/src/main/java/de/schmitzm/swing schmitzm-core/src/main/java/de/schmitzm/swing/event schmitzm-mp3/src/main/java/de/schmitzm/mp3/id3/gui
scm-commit at wald.intevation.org
scm-commit at wald.intevation.org
Fri Jun 7 20:12:10 CEST 2013
Author: mojays
Date: 2013-06-07 20:12:10 +0200 (Fri, 07 Jun 2013)
New Revision: 2333
Modified:
trunk/schmitzm-core/src/main/java/de/schmitzm/swing/SelectableJTable.java
trunk/schmitzm-core/src/main/java/de/schmitzm/swing/event/FontZoomListener.java
trunk/schmitzm-mp3/src/main/java/de/schmitzm/mp3/id3/gui/ID3TagFieldSequencePanel.java
Log:
FontZoomListener: methods renamed
Modified: trunk/schmitzm-core/src/main/java/de/schmitzm/swing/SelectableJTable.java
===================================================================
--- trunk/schmitzm-core/src/main/java/de/schmitzm/swing/SelectableJTable.java 2013-06-07 16:18:47 UTC (rev 2332)
+++ trunk/schmitzm-core/src/main/java/de/schmitzm/swing/SelectableJTable.java 2013-06-07 18:12:10 UTC (rev 2333)
@@ -75,7 +75,7 @@
/** Listener which automatically allows to resize the table's font (zoom) by
* using ALT key in combination with +/- keys or mouse wheel.
- * To remove this behavior use {@link FontZoomListener#removeFromComponent() getFontZoomListener.removeFromComponent()}. */
+ * To remove this behavior use {@link FontZoomListener#disconnectFromComponent() getFontZoomListener.removeFromComponent()}. */
protected FontZoomListener fontZoomListener = null;
@@ -144,13 +144,13 @@
SwingUtil.setAutoStopTableCellEditing(this, true);
// enable text zoom by +/- key and mouse wheel (combined with ALT)
fontZoomListener = new FontZoomListener(this);
- fontZoomListener.initComponent();
+ fontZoomListener.connectToComponent();
}
/**
* Returns the listener which automatically allows to resize the table's font
* (zoom) by using ALT key in combination with +/- keys or mouse wheel.
- * To remove this behavior use {@link FontZoomListener#removeFromComponent()}.
+ * To remove this behavior use {@link FontZoomListener#disconnectFromComponent()}.
*/
public FontZoomListener getFontZoomListener() {
return fontZoomListener;
Modified: trunk/schmitzm-core/src/main/java/de/schmitzm/swing/event/FontZoomListener.java
===================================================================
--- trunk/schmitzm-mp3/src/main/java/de/schmitzm/mp3/id3/gui/ID3TagFieldSequencePanel.java 2013-06-07 16:18:47 UTC (rev 2332)
+++ trunk/schmitzm-mp3/src/main/java/de/schmitzm/mp3/id3/gui/ID3TagFieldSequencePanel.java 2013-06-07 18:12:10 UTC (rev 2333)
@@ -163,8 +163,8 @@
clearSequence();
- new FontZoomListener(availableFields.getList(), true, false).initComponent();
- new FontZoomListener(fieldSequence.getList(), true, false).initComponent();
+ new FontZoomListener(availableFields.getList(), true, false).connectToComponent();
+ new FontZoomListener(fieldSequence.getList(), true, false).connectToComponent();
add(fieldSequenceCaption,"");
add(availableFieldsCaption,"");
More information about the Schmitzm-commits
mailing list
--- trunk/schmitzm-core/src/main/java/de/schmitzm/swing/event/FontZoomListener.java 2013-06-07 16:18:47 UTC (rev 2332)
+++ trunk/schmitzm-core/src/main/java/de/schmitzm/swing/event/FontZoomListener.java 2013-06-07 18:12:10 UTC (rev 2333)
@@ -35,7 +35,7 @@
* Creates new listener which only reacts on +/- key and mouse wheel in compination
* with ALT key. Usually the listener has to be added as {@link KeyListener} and/or
* {@link MouseWheelListener} to this component. This is not done automatically by this constructor!
* The {@link #initComponent()} method can be called to add the listeners to component.
* @param comp component to zoom the font for.
*/
public FontZoomListener(Component comp) {
@@ -45,7 +45,7 @@
/**
* Creates new listener. Usually the listener has to be added as
* {@link KeyListener} and/or {@link MouseWheelListener} to this component.
- * This is not done automatically by this constructor! The {@link #initComponent()}
+ * This is not done automatically by this constructor! The {@link #connectToComponent()}
* method can be called to add the listeners to component.
* @param comp component to zoom the font for.
* @param reactOnPlainKey indicates whether the listener should react on plain +/- keys
@@ -63,7 +63,7 @@
/**
* Adds this listener to the component as {@link KeyListener} and {@link MouseWheelListener}.
*/
- public void initComponent() {
+ public void connectToComponent() {
comp.addKeyListener(this);
comp.addMouseWheelListener(this);
}
@@ -71,7 +71,7 @@
/**
* Removed this listener from the component as {@link KeyListener} and {@link MouseWheelListener}.
*/
- public void removeFromComponent() {
+ public void disconnectFromComponent() {
comp.removeKeyListener(this);
comp.removeMouseWheelListener(this);
}
@@ -35,7 +35,7 @@
* with ALT key. Usually the listener has to be added as {@link KeyListener} and/or
* {@link MouseWheelListener} to this component. This is not done automatically by this constructor!
- * The {@link #initComponent()} method can be called to add the listeners to component.
+ * The {@link #connectToComponent()} method can be called to add the listeners to component.
* @param comp component to zoom the font for.
*/
Modified: trunk/schmitzm-mp3/src/main/java/de/schmitzm/mp3/id3/gui/ID3TagFieldSequencePanel.java
===================================================================